@@ -89,9 +89,9 @@ inline constexpr std::string_view formatVersionNumber(uint32_t Version) {
   return "unknown";
 }
 
-inline bool isSPIRVVersionKnown(uint32_t Ver) {
-  return Ver >= static_cast<uint32_t>(VersionNumber::MinimumVersion) &&
-         Ver <= static_cast<uint32_t>(VersionNumber::MaximumVersion);
+inline bool isSPIRVVersionKnown(VersionNumber Ver) {
+  return Ver >= VersionNumber::MinimumVersion &&
+         Ver <= VersionNumber::MaximumVersion;
 }
 
 enum class ExtensionID : uint32_t {
@@ -102,6 +102,8 @@ enum class ExtensionID : uint32_t {
   Last,
 };
 
+enum class ExtInst : uint32_t { None, OpenCL };
+
 enum class BIsRepresentation : uint32_t { OpenCL12, OpenCL20, SPIRVFriendlyIR };
 
 enum class FPContractMode : uint32_t { On, Off, Fast };
@@ -163,11 +165,7 @@ public:
     GenKernelArgNameMD = ArgNameMD;
   }
 
-  void enableAllExtensions() {
-#define EXT(X) ExtStatusMap[ExtensionID::X] = true;
-#include "LLVMSPIRVExtensions.inc"
-#undef EXT
-  }
+  void enableAllExtensions();
 
   void enableGenArgNameMD() { GenKernelArgNameMD = true; }
 
@@ -183,6 +181,14 @@ public:
     return true;
   }
 
+  void setExtInst(ExtInst Value) {
+    // --spirv-ext-inst supersedes --spirv-replace-fmuladd-with-ocl-mad
+    ReplaceLLVMFmulAddWithOpenCLMad = false;
+    ExtInstValue = Value;
+  }
+
+  ExtInst getExtInst() const { return ExtInstValue; }
+
   void setDesiredBIsRepresentation(BIsRepresentation Value) {
     DesiredRepresentationOfBIs = Value;
   }
@@ -227,63 +233,11 @@ public:
     PreserveOCLKernelArgTypeMetadataThroughString = Value;
   }
 
-  bool shouldEmitFunctionPtrAddrSpace() const noexcept {
-    return EmitFunctionPtrAddrSpace;
-  }
-
-  void setEmitFunctionPtrAddrSpace(bool Value) noexcept {
-    EmitFunctionPtrAddrSpace = Value;
-  }
-
   void setBuiltinFormat(BuiltinFormat Value) noexcept {
     SPIRVBuiltinFormat = Value;
   }
   BuiltinFormat getBuiltinFormat() const noexcept { return SPIRVBuiltinFormat; }
 
-  void setFnVarCategory(uint32_t Category) noexcept {
-    FnVarCategory = Category;
-  }
-  std::optional<uint32_t> getFnVarCategory() const noexcept {
-    return FnVarCategory;
-  }
-
-  void setFnVarFamily(uint32_t Family) noexcept { FnVarFamily = Family; }
-  std::optional<uint32_t> getFnVarFamily() const noexcept {
-    return FnVarFamily;
-  }
-
-  void setFnVarArch(uint32_t Arch) noexcept { FnVarArch = Arch; }
-  std::optional<uint32_t> getFnVarArch() const noexcept { return FnVarArch; }
-
-  void setFnVarTarget(uint32_t Target) noexcept { FnVarTarget = Target; }
-  std::optional<uint32_t> getFnVarTarget() const noexcept {
-    return FnVarTarget;
-  }
-
-  void setFnVarFeatures(std::vector<uint32_t> Features) noexcept {
-    FnVarFeatures = Features;
-  }
-  std::vector<uint32_t> getFnVarFeatures() const noexcept {
-    return FnVarFeatures;
-  }
-
-  void setFnVarCapabilities(std::vector<uint32_t> Capabilities) noexcept {
-    FnVarCapabilities = Capabilities;
-  }
-  std::vector<uint32_t> getFnVarCapabilities() const noexcept {
-    return FnVarCapabilities;
-  }
-
-  void setFnVarSpecEnable(bool Val) noexcept { FnVarSpecEnable = Val; }
-  bool getFnVarSpecEnable() const noexcept { return FnVarSpecEnable; }
-
-  void setFnVarSpvOut(std::string Val) noexcept { FnVarSpvOut = Val; }
-  std::string getFnVarSpvOut() const noexcept { return FnVarSpvOut; }
-
-  // Check that options passed to --fnvar-xxx flags make sense. Return true on
-  // success, false on failure.
-  bool validateFnVarOpts() const;
-
 private:
   // Common translation options
   VersionNumber MaxVersion = VersionNumber::MaximumVersion;
@@ -293,6 +247,8 @@ private:
   // SPIR-V to LLVM translation options
   bool GenKernelArgNameMD = false;
   std::unordered_map<uint32_t, uint64_t> ExternalSpecialization;
+  // Extended instruction set to use when translating from LLVM IR to SPIR-V
+  ExtInst ExtInstValue = ExtInst::None;
   // Representation of built-ins, which should be used while translating from
   // SPIR-V to back to LLVM IR
   BIsRepresentation DesiredRepresentationOfBIs = BIsRepresentation::OpenCL12;
@@ -325,21 +281,8 @@ private:
   // kernel_arg_type_qual metadata through OpString
   bool PreserveOCLKernelArgTypeMetadataThroughString = false;
 
-  // Controls if CodeSectionINTEL can be emitted and consumed with a dedicated
-  // address space
-  bool EmitFunctionPtrAddrSpace = false;
-
   bool PreserveAuxData = false;
 
-  std::optional<uint32_t> FnVarCategory = std::nullopt;
-  std::optional<uint32_t> FnVarFamily = std::nullopt;
-  std::optional<uint32_t> FnVarArch = std::nullopt;
-  std::optional<uint32_t> FnVarTarget = std::nullopt;
-  std::vector<uint32_t> FnVarFeatures = {};
-  std::vector<uint32_t> FnVarCapabilities = {};
-  std::string FnVarSpvOut = "";
-  bool FnVarSpecEnable = false;
-
   BuiltinFormat SPIRVBuiltinFormat = BuiltinFormat::Function;
 };
 
