@@ -43,11 +43,16 @@
 #include <llvm/ADT/SmallVector.h>
 #include <llvm/ADT/StringRef.h>
 #include <llvm/IR/IntrinsicInst.h>
-#include <optional>
 
 using namespace llvm;
 using namespace SPIRV;
 
+void TranslatorOpts::enableAllExtensions() {
+#define EXT(X) ExtStatusMap[ExtensionID::X] = true;
+#include "LLVMSPIRVExtensions.inc"
+#undef EXT
+}
+
 bool TranslatorOpts::isUnknownIntrinsicAllowed(IntrinsicInst *II) const
     noexcept {
   if (!SPIRVAllowUnknownIntrinsics.has_value())
@@ -69,25 +74,3 @@ void TranslatorOpts::setSPIRVAllowUnknownIntrinsics(
     TranslatorOpts::ArgList IntrinsicPrefixList) noexcept {
   SPIRVAllowUnknownIntrinsics = IntrinsicPrefixList;
 }
-
-bool TranslatorOpts::validateFnVarOpts() const {
-  if (getFnVarCategory() == std::nullopt &&
-      (getFnVarFamily() != std::nullopt || getFnVarArch() != std::nullopt)) {
-    errs() << "FnVar: Device category must be specified if the family or "
-              "architecture are specified.";
-    return false;
-  }
-
-  if (getFnVarFamily() == std::nullopt && getFnVarArch() != std::nullopt) {
-    errs() << "FnVar: Device family must be specified if the architecture is "
-              "specified.";
-    return false;
-  }
-
-  if (getFnVarTarget() == std::nullopt && !getFnVarFeatures().empty()) {
-    errs() << "Device target must be specified if the features are specified.";
-    return false;
-  }
-
-  return true;
-}
