@@ -255,6 +255,8 @@ void LLVMToSPIRVDbgTran::transLocationInfo() {
                         Col);
         }
       } // Instructions
+      // Reset current debug line at end of basic block.
+      BM->setCurrentDebugLine(nullptr);
     }   // Basic Blocks
   }     // Functions
 }
@@ -498,8 +500,6 @@ SPIRVWord LLVMToSPIRVDbgTran::mapDebugFlags(DINode::DIFlags DFlags) {
   if (BM->getDebugInfoEIS() == SPIRVEIS_NonSemantic_Shader_DebugInfo_200)
     if (DFlags & DINode::FlagBitField)
       Flags |= SPIRVDebug::FlagBitField;
-  if (DFlags & DINode::FlagEnumClass)
-    Flags |= SPIRVDebug::FlagIsEnumClass;
   return Flags;
 }
 
