@@ -83,10 +83,6 @@ public:
       BuiltIn BI = static_cast<BuiltIn>(Literals.back());
       return getCapability(BI);
     }
-    case DecorationUniform:
-      if (Module->isAllowedToUseVersion(VersionNumber::SPIRV_1_6))
-        return getVec(CapabilityUniformDecoration);
-      return getVec(CapabilityShader);
 
     default:
       return getCapability(Dec);
@@ -182,6 +178,8 @@ public:
       return ExtensionID::SPV_INTEL_fpga_cluster_attributes;
     case DecorationFuseLoopsInFunctionINTEL:
       return ExtensionID::SPV_INTEL_loop_fuse;
+    case internal::DecorationCallableFunctionINTEL:
+      return ExtensionID::SPV_INTEL_fast_composite;
     case DecorationMathOpDSPModeINTEL:
       return ExtensionID::SPV_INTEL_fpga_dsp_control;
     case DecorationInitiationIntervalINTEL:
@@ -233,8 +231,6 @@ public:
   }
 };
 
-class SPIRVDecorateString : public SPIRVDecorate {};
-
 class SPIRVDecorateId : public SPIRVDecorateGeneric {
 public:
   static const Op OC = OpDecorateId;
@@ -387,8 +383,6 @@ protected:
   SPIRVWord MemberNumber;
 };
 
-class SPIRVMemberDecorateString : public SPIRVMemberDecorate {};
-
 class SPIRVDecorationGroup : public SPIRVEntry {
 public:
   static const Op OC = OpDecorationGroup;
