@@ -76,7 +76,7 @@ class SPIRVExtInst;
   void decode(std::istream &I) override;
 
 #define _REQ_SPIRV_VER(Version)                                                \
-  SPIRVWord getRequiredSPIRVVersion() const override { return Version; }
+  VersionNumber getRequiredSPIRVVersion() const override { return Version; }
 
 // Add implementation of encode/decode functions to a class.
 // Used out side of class definition.
@@ -418,8 +418,8 @@ public:
   void validateBuiltin(SPIRVWord, SPIRVWord) const;
 
   // By default assume SPIRV 1.0 as required version
-  virtual SPIRVWord getRequiredSPIRVVersion() const {
-    return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_0);
+  virtual VersionNumber getRequiredSPIRVVersion() const {
+    return VersionNumber::SPIRV_1_0;
   }
 
   virtual std::vector<SPIRVEntry *> getNonLiteralOperands() const {
@@ -684,16 +684,16 @@ public:
     return getCapability(ExecMode);
   }
 
-  SPIRVWord getRequiredSPIRVVersion() const override {
+  VersionNumber getRequiredSPIRVVersion() const override {
     switch (ExecMode) {
     case ExecutionModeFinalizer:
     case ExecutionModeInitializer:
     case ExecutionModeSubgroupSize:
     case ExecutionModeSubgroupsPerWorkgroup:
-      return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_1);
+      return VersionNumber::SPIRV_1_1;
 
     default:
-      return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_0);
+      return VersionNumber::SPIRV_1_0;
     }
   }
 
@@ -731,8 +731,8 @@ public:
   }
   // Incomplete constructor
   SPIRVExecutionModeId() : SPIRVExecutionMode() {}
-  SPIRVWord getRequiredSPIRVVersion() const override {
-    return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_2);
+  VersionNumber getRequiredSPIRVVersion() const override {
+    return VersionNumber::SPIRV_1_2;
   }
 };
 
@@ -804,12 +804,6 @@ public:
       return nullptr;
     return Loc->second;
   }
-  SPIRVExecutionModeId *getExecutionModeId(SPIRVExecutionModeKind EMK) const {
-    auto Loc = ExecModes.find(EMK);
-    if (Loc == ExecModes.end())
-      return nullptr;
-    return static_cast<SPIRVExecutionModeId *>(Loc->second);
-  }
   SPIRVExecutionModeRange
   getExecutionModeRange(SPIRVExecutionModeKind EMK) const {
     return ExecModes.equal_range(EMK);
@@ -877,7 +871,7 @@ public:
   SPIRVCapability() : Kind(CapabilityMatrix) {}
   _SPIRV_DCL_ENCDEC
 
-  SPIRVWord getRequiredSPIRVVersion() const override {
+  VersionNumber getRequiredSPIRVVersion() const override {
     switch (Kind) {
     case CapabilityGroupNonUniform:
     case CapabilityGroupNonUniformVote:
@@ -886,15 +880,15 @@ public:
     case CapabilityGroupNonUniformShuffle:
     case CapabilityGroupNonUniformShuffleRelative:
     case CapabilityGroupNonUniformClustered:
-      return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_3);
+      return VersionNumber::SPIRV_1_3;
 
     case CapabilityNamedBarrier:
     case CapabilitySubgroupDispatch:
     case CapabilityPipeStorage:
-      return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_1);
+      return VersionNumber::SPIRV_1_1;
 
     default:
-      return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_0);
+      return VersionNumber::SPIRV_1_0;
     }
   }
 
@@ -907,11 +901,12 @@ public:
     case CapabilityVectorComputeINTEL:
     case CapabilityVectorAnyINTEL:
       return ExtensionID::SPV_INTEL_vector_compute;
-    case CapabilityFunctionVariantsINTEL:
-    case CapabilitySpecConditionalINTEL:
-      return ExtensionID::SPV_INTEL_function_variants;
-    case internal::CapabilityBFloat16ArithmeticINTEL:
-      return ExtensionID::SPV_INTEL_bfloat16_arithmetic;
+    case internal::CapabilityFastCompositeINTEL:
+      return ExtensionID::SPV_INTEL_fast_composite;
+    case internal::CapabilitySubgroupRequirementsINTEL:
+      return ExtensionID::SPV_INTEL_subgroup_requirements;
+    case CapabilityFPFastMathModeINTEL:
+      return ExtensionID::SPV_INTEL_fp_fast_math_mode;
     default:
       return {};
     }
@@ -1028,8 +1023,8 @@ public:
   SPIRVModuleProcessed() { updateModuleVersion(); }
   _SPIRV_DCL_ENCDEC
   void validate() const override;
-  SPIRVWord getRequiredSPIRVVersion() const override {
-    return static_cast<SPIRVWord>(VersionNumber::SPIRV_1_1);
+  VersionNumber getRequiredSPIRVVersion() const override {
+    return VersionNumber::SPIRV_1_1;
   }
 
   std::string getProcessStr();
@@ -1093,6 +1088,7 @@ _SPIRV_OP(NamedBarrierInitialize)
 _SPIRV_OP(MemoryNamedBarrier)
 _SPIRV_OP(GetKernelMaxNumSubgroups)
 _SPIRV_OP(GetKernelLocalSizeForSubgroupCount)
+_SPIRV_OP(SizeOf)
 #undef _SPIRV_OP
 
 } // namespace SPIRV
