@@ -29,10 +29,6 @@ _SPIRV_OP(InvalidVersionNumber,
           "Invalid Version Number.")
 _SPIRV_OP(UnspecifiedMemoryModel, "Unspecified Memory Model.")
 _SPIRV_OP(RepeatedMemoryModel, "Expects a single OpMemoryModel instruction.")
-_SPIRV_OP(DeprecatedExtension,
-          "Feature requires the following deprecated SPIR-V extension:\n")
-_SPIRV_OP(InvalidNumberOfOperands,
-          "Number of operands does not match the expected count.")
 
 /* This is the last error code to have a maximum valid value to compare to */
 _SPIRV_OP(InternalMaxErrorCode, "Unknown error code")
