@@ -115,14 +115,6 @@ inline bool isCvtOpCode(Op OpCode) {
          OpCode == OpCrossWorkgroupCastToPtrINTEL;
 }
 
-inline bool isIntelCvtOpCode(Op OpCode) {
-  return OpCode == internal::OpClampConvertFToFINTEL ||
-         OpCode == internal::OpClampConvertFToSINTEL ||
-         OpCode == internal::OpStochasticRoundFToFINTEL ||
-         OpCode == internal::OpClampStochasticRoundFToFINTEL ||
-         OpCode == internal::OpClampStochasticRoundFToSINTEL;
-}
-
 inline bool isCvtToUnsignedOpCode(Op OpCode) {
   return OpCode == OpConvertFToU || OpCode == OpUConvert ||
          OpCode == OpSatConvertSToU;
@@ -239,27 +231,19 @@ inline bool isTypeOpCode(Op OpCode) {
          isVCOpCode(OpCode) || OC == internal::OpTypeTokenINTEL ||
          OC == internal::OpTypeJointMatrixINTEL ||
          OC == internal::OpTypeJointMatrixINTELv2 ||
-         OC == OpTypeCooperativeMatrixKHR;
-}
-
-inline bool isFnVarSpecConstINTEL(Op OpCode) {
-  unsigned OC = OpCode;
-  return OC == OpSpecConstantArchitectureINTEL ||
-         OC == OpSpecConstantTargetINTEL ||
-         OC == OpSpecConstantCapabilitiesINTEL;
+         OC == OpTypeCooperativeMatrixKHR ||
+         OC == internal::OpTypeTaskSequenceINTEL;
 }
 
 inline bool isSpecConstantOpCode(Op OpCode) {
   unsigned OC = OpCode;
-  return (OpSpecConstantTrue <= OC && OC <= OpSpecConstantOp) ||
-         isFnVarSpecConstINTEL(OpCode);
+  return OpSpecConstantTrue <= OC && OC <= OpSpecConstantOp;
 }
 
 inline bool isConstantOpCode(Op OpCode) {
   unsigned OC = OpCode;
   return (OpConstantTrue <= OC && OC <= OpSpecConstantOp) || OC == OpUndef ||
-         OC == OpConstantPipeStorage || OC == OpConstantFunctionPointerINTEL ||
-         isSpecConstantOpCode(OpCode);
+         OC == OpConstantPipeStorage || OC == OpConstantFunctionPointerINTEL;
 }
 
 inline bool isModuleScopeAllowedOpCode(Op OpCode) {
