@@ -291,7 +291,6 @@ _SPIRV_OP(ImageSparseTexelsResident, 316)
 _SPIRV_OP(NoLine, 317)
 _SPIRV_OP(AtomicFlagTestAndSet, 318)
 _SPIRV_OP(AtomicFlagClear, 319)
-_SPIRV_OP(SizeOf, 321)
 _SPIRV_OP(TypePipeStorage, 322)
 _SPIRV_OP(ConstantPipeStorage, 323)
 _SPIRV_OP(CreatePipeFromPipeStorage, 324)
@@ -366,8 +365,6 @@ _SPIRV_OP(AtomicFMinEXT, 5614)
 _SPIRV_OP(AtomicFMaxEXT, 5615)
 _SPIRV_OP(AssumeTrueKHR, 5630)
 _SPIRV_OP(ExpectKHR, 5631)
-_SPIRV_OP(DecorateString, 5632)
-_SPIRV_OP(MemberDecorateString, 5633)
 _SPIRV_OP(VmeImageINTEL, 5699)
 _SPIRV_OP(TypeVmeImageINTEL, 5700)
 _SPIRV_OP(TypeAvcImePayloadINTEL, 5701)
@@ -563,21 +560,6 @@ _SPIRV_OP(ConstantCompositeContinuedINTEL, 6091)
 _SPIRV_OP(SpecConstantCompositeContinuedINTEL, 6092)
 _SPIRV_OP(ControlBarrierArriveINTEL, 6142)
 _SPIRV_OP(ControlBarrierWaitINTEL, 6143)
-_SPIRV_OP(ArithmeticFenceEXT, 6145)
-_SPIRV_OP(Subgroup2DBlockLoadINTEL, 6231)
-_SPIRV_OP(Subgroup2DBlockLoadTransformINTEL, 6232)
-_SPIRV_OP(Subgroup2DBlockLoadTransposeINTEL, 6233)
-_SPIRV_OP(Subgroup2DBlockPrefetchINTEL, 6234)
-_SPIRV_OP(Subgroup2DBlockStoreINTEL, 6235)
-_SPIRV_OP(SubgroupMatrixMultiplyAccumulateINTEL, 6237)
-_SPIRV_OP(BitwiseFunctionINTEL, 6242)
-_SPIRV_OP(ConditionalExtensionINTEL, 6248)
-_SPIRV_OP(ConditionalEntryPointINTEL, 6249)
-_SPIRV_OP(ConditionalCapabilityINTEL, 6250)
-_SPIRV_OP(SpecConstantTargetINTEL, 6251)
-_SPIRV_OP(SpecConstantArchitectureINTEL, 6252)
-_SPIRV_OP(SpecConstantCapabilitiesINTEL, 6253)
-_SPIRV_OP(ConditionalCopyObjectINTEL, 6254)
 _SPIRV_OP(GroupIMulKHR, 6401)
 _SPIRV_OP(GroupFMulKHR, 6402)
 _SPIRV_OP(GroupBitwiseAndKHR, 6403)
