@@ -135,6 +135,17 @@ static cl::opt<bool> SPIRVGenKernelArgNameMD(
     cl::desc("Enable generating OpenCL kernel argument name "
              "metadata"));
 
+static cl::opt<SPIRV::ExtInst> ExtInst(
+    "spirv-ext-inst",
+    cl::desc("Specify the extended instruction set to use when "
+             "translating from a LLVM intrinsic function to SPIR-V.  "
+             "If none, some LLVM intrinsic functions will be emulated."),
+    cl::values(clEnumValN(SPIRV::ExtInst::None, "none",
+                          "No extended instructions"),
+               clEnumValN(SPIRV::ExtInst::OpenCL, "OpenCL.std",
+                          "OpenCL.std extended instruction set")),
+    cl::init(SPIRV::ExtInst::None));
+
 static cl::opt<SPIRV::BIsRepresentation> BIsRepresentation(
     "spirv-target-env",
     cl::desc("Specify a representation of different SPIR-V Instructions which "
@@ -156,10 +167,6 @@ static cl::opt<bool>
     SPIRVToolsDis("spirv-tools-dis", cl::init(false),
                   cl::desc("Emit textual assembly using SPIRV-Tools"));
 
-static cl::opt<bool> SPIRVEmitFunctionPtrAddrSpace(
-    "spirv-emit-function-ptr-addr-space", cl::init(false),
-    cl::desc("Emit and consume CodeSectionINTEL for function pointers"));
-
 using SPIRV::ExtensionID;
 
 #ifdef _SPIRV_SUPPORT_TEXT_FMT
@@ -257,7 +264,7 @@ static cl::opt<SPIRV::DebugInfoEIS> DebugEIS(
 static cl::opt<bool> SPIRVReplaceLLVMFmulAddWithOpenCLMad(
     "spirv-replace-fmuladd-with-ocl-mad",
     cl::desc("Allow replacement of llvm.fmuladd.* intrinsic with OpenCL mad "
-             "instruction from OpenCL extended instruction set"),
+             "instruction from OpenCL extended instruction set (deprecated)"),
     cl::init(true));
 
 static cl::opt<SPIRV::BuiltinFormat> SPIRVBuiltinFormat(
@@ -270,59 +277,6 @@ static cl::opt<SPIRV::BuiltinFormat> SPIRVBuiltinFormat(
         clEnumValN(SPIRV::BuiltinFormat::Global, "global",
                    "Use globals to represent SPIR-V builtin variables")));
 
-static cl::opt<uint32_t> FnVarCategory(
-    "fnvar-category",
-    cl::desc("Specify architecture category of the target device (omitting "
-             "this flag denotes that the target device can be of any "
-             "category). Used only with -r and --fnvar-spec-enable."),
-    cl::value_desc("category"), cl::ValueRequired);
-
-static cl::opt<uint32_t> FnVarFamily(
-    "fnvar-family",
-    cl::desc("Specify architecture family of the target device (omitting this "
-             "flag denotes that the target device can be of any family). Used "
-             "only with -r and --fnvar-spec-enable."),
-    cl::value_desc("family"), cl::ValueRequired);
-
-static cl::opt<uint32_t> FnVarArch(
-    "fnvar-arch",
-    cl::desc("Specify architecture of the target device (omitting this flag "
-             "denotes that the target device can be of any architecture). Used "
-             "only with -r and --fnvar-spec-enable."),
-    cl::value_desc("architecture"), cl::ValueRequired);
-
-static cl::opt<uint32_t>
-    FnVarTarget("fnvar-target",
-                cl::desc("Specify target of the target device (omitting this "
-                         "flag denotes that the target device can be any "
-                         "target). Used only with -r and --fnvar-spec-enable."),
-                cl::value_desc("target"), cl::ValueRequired);
-
-static cl::list<uint32_t> FnVarFeatures(
-    "fnvar-features", cl::CommaSeparated,
-    cl::desc("Specify features of the target device (omitting this flag "
-             "denotes that the target device supports all features). Used only "
-             "with -r and --fnvar-spec-enable."),
-    cl::value_desc("feature0,feature1,..."), cl::ValueRequired);
-
-static cl::list<uint32_t> FnVarCapabilities(
-    "fnvar-capabilities", cl::CommaSeparated,
-    cl::desc("Specify capabilities of the target device (omitting this flag "
-             "denotes that the target device supports all features). Used only "
-             "with -r and --fnvar-spec-enable."),
-    cl::value_desc("capability0,capability1,..."), cl::ValueRequired);
-
-static cl::opt<std::string> FnVarSpvOut(
-    "fnvar-spv-out",
-    cl::desc("Save the specialized target-specific SPIR-V module to this file. "
-             "Used only with -r and --fnvar-spec-enable."),
-    cl::value_desc("file"), cl::ValueRequired);
-
-static cl::opt<bool> FnVarSpecEnable(
-    "fnvar-spec-enable", cl::init(false),
-    cl::desc("Enable specialization of function variants according to "
-             "SPV_INTEL_function_variants. Requires -r flag."));
-
 static std::string removeExt(const std::string &FileName) {
   size_t Pos = FileName.find_last_of(".");
   if (Pos != std::string::npos)
@@ -765,6 +719,24 @@ int main(int Ac, char **Av) {
     return Ret;
 
   SPIRV::TranslatorOpts Opts(MaxSPIRVVersion, ExtensionsStatus);
+
+  if (ExtInst.getNumOccurrences() != 0) {
+    if (ExtInst.getNumOccurrences() > 1) {
+      errs() << "Error: --spirv-ext-inst cannot be used more than once\n";
+      return -1;
+    } else if (SPIRVReplaceLLVMFmulAddWithOpenCLMad.getNumOccurrences()) {
+      errs()
+          << "Error: --spirv-ext-inst and --spirv-replace-fmuladd-with-ocl-mad "
+             "cannot be used together.  --spirv-replace-fmuladd-with-ocl-mad "
+             "is deprecated and --spirv-ext-inst is preferred.\n";
+      return -1;
+    } else if (IsReverse) {
+      errs() << "Note: --spirv-ext-inst option ignored as it only "
+                "affects translation from LLVM IR to SPIR-V";
+    }
+    Opts.setExtInst(ExtInst);
+  }
+
   if (BIsRepresentation.getNumOccurrences() != 0) {
     if (!IsReverse) {
       errs() << "Note: --spirv-target-env option ignored as it only "
@@ -847,59 +819,6 @@ int main(int Ac, char **Av) {
   if (PreserveOCLKernelArgTypeMetadataThroughString.getNumOccurrences() != 0)
     Opts.setPreserveOCLKernelArgTypeMetadataThroughString(true);
 
-  if (SPIRVEmitFunctionPtrAddrSpace.getNumOccurrences() != 0)
-    Opts.setEmitFunctionPtrAddrSpace(true);
-
-  Opts.setFnVarSpecEnable(FnVarSpecEnable);
-
-  if (!IsReverse &&
-      (FnVarSpecEnable || FnVarCategory != 0 || FnVarFamily != 0 ||
-       FnVarArch != 0 || FnVarTarget != 0 || !FnVarFeatures.empty() ||
-       !FnVarCapabilities.empty() || !FnVarSpvOut.empty())) {
-    errs() << "--fnvar-xxx flags can be used only with -r\n";
-    return -1;
-  }
-
-  if (!FnVarSpecEnable &&
-      (FnVarCategory != 0 || FnVarFamily != 0 || FnVarArch != 0 ||
-       FnVarTarget != 0 || !FnVarFeatures.empty() ||
-       !FnVarCapabilities.empty() || !FnVarSpvOut.empty())) {
-    errs() << "--fnvar-xxx flags need to be enabled with --fnvar-spec-enable\n";
-    return -1;
-  }
-
-  if (FnVarCategory.getNumOccurrences() > 0) {
-    Opts.setFnVarCategory(FnVarCategory);
-  }
-
-  if (FnVarFamily.getNumOccurrences() > 0) {
-    Opts.setFnVarFamily(FnVarFamily);
-  }
-
-  if (FnVarArch.getNumOccurrences() > 0) {
-    Opts.setFnVarArch(FnVarArch);
-  }
-
-  if (FnVarTarget.getNumOccurrences() > 0) {
-    Opts.setFnVarTarget(FnVarTarget);
-  }
-
-  if (!FnVarFeatures.empty()) {
-    Opts.setFnVarFeatures(FnVarFeatures);
-  }
-
-  if (!FnVarCapabilities.empty()) {
-    Opts.setFnVarCapabilities(FnVarCapabilities);
-  }
-
-  if (!FnVarSpvOut.empty()) {
-    Opts.setFnVarSpvOut(FnVarSpvOut);
-  }
-
-  if (!Opts.validateFnVarOpts()) {
-    return -1;
-  }
-
 #ifdef _SPIRV_SUPPORT_TEXT_FMT
   if (ToText && (ToBinary || IsReverse || IsRegularization)) {
     errs() << "Cannot use -to-text with -to-binary, -r, -s\n";
